package Data::CompactReadonly::V0::Scalar::NegativeByte;
our $VERSION = '0.0.6';

use warnings;
use strict;
use base qw(
    Data::CompactReadonly::V0::NegativeScalar
    Data::CompactReadonly::V0::Scalar::Byte
);

1;
